# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/54_tens.ipynb.

# %% auto 0
__all__ = ['Tensor', 'Device']

# %% ../nbs/54_tens.ipynb 6
import inspect
from numbers import Number

# %% ../nbs/54_tens.ipynb 8
import types
from typing import (
    Type, TypeAlias, Tuple,
    ClassVar, Any, Optional, Callable, Iterable, ForwardRef
)
from typing import TypeAlias, List, Union, Iterable, List

# %% ../nbs/54_tens.ipynb 11
try:
    import torch
    tensor = torch.Tensor
    device = torch.device
except ImportError:
    # Define a placeholder type if torch is not installed
    tensor = 'torch.Tensor'
    device = 'torch.device'

# %% ../nbs/54_tens.ipynb 13
#| export


# %% ../nbs/54_tens.ipynb 15
from .nums import Numbers

# %% ../nbs/54_tens.ipynb 18
Tensor: TypeAlias = tensor
Device: TypeAlias = device
